@charset "utf-8";
/*
 * このファイルを編集して、profile-directory/chrome/userChrome.css
 * としてコピーしてください。
 */

/*
 * このファイルは、Mozilla のユーザインタフェース(UI) の外観をカスタマイズ
 * するのに使用することができます。
 * デフォルト設定の無効化宣言 !important を使用する事を忘れないでください。
 */

/*
 * @namespace 行は削除しないでください － 正しく機能するために必要です。
 */
@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* set default namespace to XUL */


/*
 * 操作性を向上させる有効な例:
 */
/*
 * デフォルトフォントサイズをすべて 20 ポイントにする:
 *
 * * {
 *   font-size: 20pt !important
 * }
 */
/*
 * デフォルトサイズの代わりに特に、メニュー項目を 15 ポイントにする:
 *
 * menupopup > * {
 *   font-size: 15pt !important
 * }
 */
/*
 * ロケーション (URL) バーに固定幅フォントの使用を強制する:
 *
 * #urlbar {
 *    font-family: monospace !important;
 * }
 */

/*
 * Throbber と不快で迷惑な動作を無効にする:
 *
 * #throbber-box {
 *   display: none !important;
 * }
 */

/*
 * さらに多くの事例は、 http://www.mozilla.org/unix/customizing.html
 * を参照してください。
 */
 
