//@line 36 "/builds/tinderbox/Fx-Mozilla1.8.0-l10n-Release/Linux_2.4.21-37.EL_Depend/mozilla/browser/locales/../../../l10n/ja-JP-mac/browser/firefox-l10n.js"

//@line 38 "/builds/tinderbox/Fx-Mozilla1.8.0-l10n-Release/Linux_2.4.21-37.EL_Depend/mozilla/browser/locales/../../../l10n/ja-JP-mac/browser/firefox-l10n.js"

pref("general.useragent.locale", "ja-JP-mac");

pref("browser.search.order.3", "chrome://browser-region/locale/region.properties");
pref("browser.search.order.4", "chrome://browser-region/locale/region.properties");
pref("browser.search.order.5", "chrome://browser-region/locale/region.properties");
pref("browser.search.order.6", "chrome://browser-region/locale/region.properties");
pref("browser.search.order.7", "chrome://browser-region/locale/region.properties");
pref("browser.search.order.8", "chrome://browser-region/locale/region.properties");
